@@ -1,4 +1,5 @@
 import pathlib
+import warnings
 from augpathlib import exceptions as exc
 from augpathlib.meta import PathMeta
 from augpathlib.core import AugmentedPath, EatHelper
@@ -41,6 +42,12 @@ class CachePath(AugmentedPath):
     @classmethod
     def setup(cls, local_class, remote_class_factory):
         """ call this once to bind everything together """
+
+        cn = self.__class__.__name__
+        warnings.warn(f'{cn}.setup is deprecated please switch to RemotePath._new',
+                      DeprecationWarning,
+                      stacklevel=2)
+
         cls._local_class = local_class
         cls._remote_class_factory = remote_class_factory
         local_class._cache_class = cls
@@ -53,17 +60,26 @@ class CachePath(AugmentedPath):
 
     @classmethod
     def weighAnchor(cls):
-        # FIXME should this return the old anchor?
+        # return a value to indicate that there was an anchor since
+        # we no longer error when already underway
         acls = cls._abstract_class()
         if hasattr(acls, '_anchor'):
-            delattr(acls, '_anchor')
-        else:
-            raise ValueError(f'{self.__class__} not anchored')
+            return delattr(acls, '_anchor')
 
-    def anchorClassHere(self):
+    def anchorClassHere(self, remote_init=True):
         """ Use this to initialize the class level anchor from an instance. """
+
+        # FIXME WARNING you can shoot yourself in the foot with this if
+        # there is another anchor further up the tree from this one
+        # FIXME further, this means that there has to have been a way
+        # to construct a live CachePath by sideloading the remote id
+        # which is OK for the path where local/remote binding has already
+        # been completed
         if not hasattr(self.__class__, '_anchor'):
             self.__class__._abstract_class()._anchor = self
+            self.local_data_dir_init()  # call every time for insurance
+            self._remote_class.anchorToCache(self, init=remote_init)
+
         else:
             raise ValueError(f'{self.__class__} already anchored to {self.__class__._anchor}')
 
@@ -165,22 +181,29 @@ class CachePath(AugmentedPath):
         # modify new to never call it again?
         self.local_data_dir.mkdir(exist_ok=exist_ok)
         self.local_objects_dir.mkdir(exist_ok=exist_ok)
-        self.trash.mkdir(exist_ok=exist_ok)
+        try:
+            self.trash.mkdir(exist_ok=exist_ok)
+        except NotImplementedError:
+            # if there's no trash, there's no trash
+            pass
 
     @property
     def is_helper_cache(self):
         return hasattr(self, '_cache_parent')
 
-    def __truediv__(self, key):
+    def __truediv__(self, key, update_meta=True):
         # basically RemotePaths are like relative CachePaths ... HRM
         # they are just a name and an id ... the id of their parent
         # root needs to match the id of the cache ... which it usually
         # does by construction
+        parent = self.parent if self.parent.meta is not None else self  # FIXME should be in def parent ???
         if isinstance(key, remotes.RemotePath):
             # FIXME not just names but relative paths???
             remote = key
             try:
-                child = self._make_child(remote._parts_relative_to(self.remote, self.parent), remote)
+                child = self._make_child(
+                    remote._parts_relative_to(self.remote, parent),
+                    remote, update_meta=update_meta)
             except AttributeError as e:
                 raise exc.AugPathlibError('aaaaaaaaaaaaaaaaaaaaaa') from e
 
@@ -199,14 +222,14 @@ class CachePath(AugmentedPath):
         #out._meta_setter(cache.meta)
         return out
 
-    def _make_child(self, args, remote):
+    def _make_child(self, args, remote, update_meta=True):
         drv, root, parts = self._parse_args(args)
         drv, root, parts = self._flavour.join_parsed_parts(
             self._drv, self._root, self._parts, drv, root, parts)
         child = self._from_parsed_parts(drv, root, parts, init=False)  # short circuits
         child._init()
         if isinstance(remote, remotes.RemotePath):
-            remote._cache_setter(child)
+            remote._cache_setter(child, update_meta=update_meta)
         else:
             raise ValueError('should not happen')
 
@@ -559,6 +582,7 @@ class CachePath(AugmentedPath):
         if root is None:
             #breakpoint()
             raise exc.NotInProjectError(f'{self.parent.local} is not in a project!')
+
         breakpoint()
         raise NotImplementedError()
         children = list(self.parent.remote.children)  # if this is run from dismatch meta we have issues
@@ -620,6 +644,7 @@ class CachePath(AugmentedPath):
     def refresh(self, update_data=False, size_limit_mb=2, force=False):
         if self.meta is None:
             breakpoint()
+
         limit = (size_limit_mb if
                  not self.meta.size or (size_limit_mb > self.meta.size.mb)
                  else self.meta.size.mb + 1)
@@ -676,7 +701,7 @@ class CachePath(AugmentedPath):
         # deal with moving to a different directory that might not even exist yet
         if target is None:
             if not isinstance(self.anchor, self.__class__):
-                raise TypeError('mismatched anchor types {self!r} {self.anchor!r}')
+                raise TypeError(f'mismatched anchor types {self!r} {self.anchor!r}')
 
             target = self.anchor / remote  # FIXME why does this not try to instantiate the caches? or does it?
 
@@ -762,6 +787,10 @@ class CachePath(AugmentedPath):
                   if self.remote else str(self.id))
         return self.__class__.__name__ + ' <' + local + ' -> ' + remote + '>'
 
+    @property
+    def data(self):
+        raise NotImplementedError('implement in subclass')
+
 
 CachePath._bind_flavours()
 
@@ -1053,10 +1082,11 @@ class PrimaryCache(CachePath):
 
         return file_is_different, PathMeta(**kwargs)
 
-    def _meta_updater(self, pathmeta):
+    def _meta_updater(self, pathmeta, fetch=True):
         original = self.meta
         file_is_different, updated = self._update_meta(original, pathmeta)
-        must_fetch = file_is_different and self.is_file() and self.exists()
+        # FIXME missing checksum is one source of problems here
+        must_fetch = file_is_different and self.is_file() and self.exists() and fetch
 
         if must_fetch:
             try:
@@ -1125,6 +1155,14 @@ class SshCache(PrimaryCache, EatCache):
     _not_exists_cache = SymlinkCache
     cypher = default_cypher
 
+    # FIXME probably need a way to dispatch to multiple remotes
+    # based on that prefix, since the id actually determines the
+    # remote class in this case since the class maintains the session
+    # after init, the hostname is materialized into the id to disambiguate
+    # the local path specifications
+
+    checksum = AugmentedPath.checksum
+
     @property
     def anchor(self):
         if not hasattr(self, '_anchor') or self._anchor is None:
