@@ -2,6 +2,7 @@ import os
 import sys
 import shutil
 import pathlib
+import warnings
 import mimetypes
 import subprocess
 from time import sleep
@@ -17,6 +18,7 @@ except (ImportError, TypeError) as e:
 #import psutil  # import for experimental xopen functionality
 #from Xlib.display import Display
 #from Xlib import Xatom
+import augpathlib as aug
 from augpathlib import exceptions as exc
 from augpathlib.meta import PathMeta
 from augpathlib.utils import log, default_cypher, StatResult, etag
@@ -662,8 +664,21 @@ class LocalPath(EatPath, AugmentedPath):
     @classmethod
     def setup(cls, cache_class, remote_class_factory):
         """ call this once to bind everything together """
+
+        cn = self.__class__.__name__
+        warnings.warn(f'{cn}.setup is deprecated please switch to RemotePath._new',
+                      DeprecationWarning,
+                      stacklevel=2)
+
         cache_class.setup(cls, remote_class_factory)
 
+    #def __truediv__(self, other):
+        # TODO need a way to get the remote relative to the anchor for this
+        #if isinstance(other, aug.RemotePath):
+            #super().__truediv__(other.as_path())
+        #else:
+            #super().__truediv__(other)
+
     @property
     def remote(self):
         return self.cache.remote
@@ -686,7 +701,9 @@ class LocalPath(EatPath, AugmentedPath):
         return self._cache
 
     def cache_init(self, id_or_meta, anchor=False):
-        """ wow it took way too long to realize this was the way to do it >_< """
+        """ wow it took way too long to realize this was the way to do it >_<
+            **kwargs are passed to _cache_class and _remote_class.init """
+
         if self.cache and self.cache.meta:
             raise exc.CacheExistsError(f'{self.cache}\n'
                                        f'{self.cache.meta}')
@@ -741,8 +758,10 @@ class LocalPath(EatPath, AugmentedPath):
             # just act like paths rathern than forcing them to exist which causes all
             # sorts of awkwardness, including the RemoteMaybeExists issue
             self.mkdir(exist_ok=True)
-            self.cache_init(remote.meta)
-            remote._cache = self.cache
+            if remote.cache is None:
+                self.cache_init(remote.meta)
+                remote._cache = self.cache
+
             return remote
 
         elif parents:
